#[non_exhaustive]pub enum EffectReconciliation {
Completed(Value),
NotExecuted,
Ambiguous,
}Expand description
Result of querying an external system for an ambiguously started effect.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
Completed(Value)
The remote operation completed and this is its canonical output.
NotExecuted
The remote system proves the operation did not execute.
Ambiguous
The remote system cannot determine the outcome safely.