#[non_exhaustive]pub enum EffectStatus {
Prepared,
Started,
Completed {
output: Value,
},
Failed {
error: RunError,
},
}Expand description
Persisted external-effect state.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
Prepared
The request is durable and no handler has been started.
Started
The handler may be executing or may have executed.
Completed
The effect completed with a durable output.
Failed
The handler returned a durable failure.